@@ -45,7 +45,7 @@ def test_no_additional_name_in_table_name():
     assert _cast_table_name("TableName") == "TableName"
 
 
-@mock_dynamodb2
+# @mock_dynamodb2
 class TestDynamoDBBase(TestCase):
     table_name = "TableForTests"
     actual_cwd = str()
@@ -66,11 +66,11 @@ class TestDynamoDBBase(TestCase):
         self.raw_schema = load_single(
             Path(Path(__file__).parent, f"test_data/tables/{self.table_name}.json")
         )
-        create_dynamo_db_table_from_schema(self.raw_schema)
+        # create_dynamo_db_table_from_schema(self.raw_schema)
 
     def tearDown(self) -> None:
         from dynamo_db_resource.table_existence import delete_dynamo_db_table
-        delete_dynamo_db_table(self.table_name, require_confirmation=False)
+        # delete_dynamo_db_table(self.table_name, require_confirmation=False)
         chdir(self.actual_cwd)
 
 
@@ -896,7 +896,7 @@ class TestDynamoDB(TestDynamoDBBase):
         response = t.update_attribute(updated_attribute, returns=UpdateReturns.UPDATED_NEW, **test_item_primary)
 
         self.assertEqual(
-            updated_attribute, response
+            249235.93, response
         )
 
         self.assertEqual(
@@ -905,6 +905,47 @@ class TestDynamoDB(TestDynamoDBBase):
 
         t.delete(**test_item_primary)
 
+    def test_update_with_nested_attribute_return_new_values(self):
+        updated_attribute = {"some_nested_dict": {"KEY1": {"subKEY2": 342.98}}}
+        from dynamo_db_resource import Table, UpdateReturns
+
+        t = Table(self.table_name)
+
+        t.put(test_item)
+
+        response = t.update_attribute(updated_attribute, returns=UpdateReturns.UPDATED_NEW, **test_item_primary)
+
+        self.assertEqual(
+            342.98, response
+        )
+
+        self.assertEqual(
+            updated_attribute["some_nested_dict"]["KEY1"]["subKEY2"],
+            t.get(**test_item_primary)["some_nested_dict"]["KEY1"]["subKEY2"],
+        )
+
+        t.delete(**test_item_primary)
+
+    def test_update_with_set_attribute_return_new_values(self):
+        updated_attribute = {"some_string_set": {"abc"}}
+        from dynamo_db_resource import Table, UpdateReturns
+
+        t = Table(self.table_name)
+
+        t.put(test_item)
+
+        response = t.update_attribute(updated_attribute, set_new_attribute_if_not_existent=True, returns=UpdateReturns.UPDATED_NEW, **test_item_primary)
+
+        self.assertEqual(
+            {"abc"}, response
+        )
+
+        self.assertEqual(
+            updated_attribute["some_string_set"], t.get(**test_item_primary)["some_string_set"],
+        )
+
+        t.delete(**test_item_primary)
+
     def test_update_with_attribute_return_old_values(self):
         updated_attribute = {"some_float": 249235.93}
         from dynamo_db_resource import Table, UpdateReturns
@@ -916,7 +957,7 @@ class TestDynamoDB(TestDynamoDBBase):
         response = t.update_attribute(updated_attribute, returns=UpdateReturns.UPDATED_OLD, **test_item_primary)
 
         self.assertEqual(
-            {"some_float": test_item["some_float"]}, response
+            test_item["some_float"], response
         )
 
         self.assertEqual(
@@ -1239,6 +1280,23 @@ class TestDynamoDB(TestDynamoDBBase):
             t.get(**test_item_primary)["some_string_set"]
         )
 
+    def test_removing_non_existing_items_from_set(self):
+        from dynamo_db_resource import Table
+
+        t = Table(self.table_name)
+        t.put(test_item)
+        t.add_new_attribute({"some_string_set": {"2", "3", "4", "5"}}, **test_item_primary)
+        with self.assertRaises(KeyError):
+            t.remove_from_set(["some_string_set"], {"7"}, **test_item_primary)
+
+    def test_removing_from_non_existing_set(self):
+        from dynamo_db_resource import Table
+
+        t = Table(self.table_name)
+        t.put(test_item)
+        with self.assertRaises(KeyError):
+            t.remove_from_set(["some_string_set"], {"7"}, **test_item_primary)
+
     def test_remove_attribute(self):
         from dynamo_db_resource import Table
         t = Table(self.table_name)
